GrowableVmars

Struct GrowableVmars 

pub struct GrowableVmars { /* private fields */ }
Implements a list of VMARs that grows, but never shrinks, to support additional allocations.

This does not actually track allocations and frees, but rather allows for performing a probe just prior to allocation to find a VMAR that has space. Although probing is less efficient, this is useful if the exact amounts allocated, and when they are freed, cannot be easily tracked.

Implementations

Source

impl GrowableVmars

pub fn probe(&mut self) -> Result<Arc<Vmar>, Errno>

Returns a handle to a VMAR that has at least PROBE_SIZE bytes of free space.

The returned handle is suitable for passing to thrd_set_zx_create_handles via the thrd_zx_create_handles_t structure.

pub fn new() -> GrowableVmars

Creates a new empty GrowableVmars.